@@ -27,7 +27,6 @@ from ..interfaces.resource import (
     Resource,
     ResourceState,
     ResourceUploader,
-    ResourceVisibility,
     SyncResourceUploader,
 )
 from ..storage.db import DB
@@ -73,7 +72,7 @@ def _get_or_create_dataset(id: Optional[str]=None,
                 )
                 DB().delete_local_dataset(id=local_id)
         dset = Dataset(name=name, description="SDK_QUICKSTART",
-                       visibility=ResourceVisibility.PRIVATE,
+                       public=False,
                        filename=f"{name}.zip",
                        is_zipfile=True)
         dset.save()
@@ -123,7 +122,7 @@ def _get_or_create_model(id: Optional[str]=None,
                 )
                 DB().delete_local_model(id=local_id)
         model = Model(name=name, description="SDK_QUICKSTART",
-                      visibility=ResourceVisibility.PRIVATE,
+                      public=False,
                       filename=f"{name}.zip",
                       is_zipfile=True,
                       algorithm_id=algorithm.id)
@@ -258,7 +257,7 @@ def quick_train(algorithm_id: Optional[str]=None,
                 algorithm_force_update: bool=False,
                 algorithm_git_ref: Optional[str]=None,
                 dataset_hyperparam_name: str="dataset",
-                dataset_id: Optional[str]=None,
+                dataset_id: Optional[Union[List[str], str]]=None,
                 dataset_dir: Optional[Union[str, Path]]=None,
                 dataset_archive: Optional[str]=None,
                 model_hyperparam_name: str="model",
@@ -421,6 +420,16 @@ def quick_train(algorithm_id: Optional[str]=None,
         for _id in model_id
     ]
 
+    # Remote dataset
+    if dataset_id is None:
+        dataset_id = []
+    elif not isinstance(dataset_id, list):
+        dataset_id = [dataset_id]
+    datasets = [
+        Dataset(id=_id, load_detail=True)
+        for _id in dataset_id
+    ]
+
     # Remote pretrain task results
     if pretrain_task_id is None:
         pretrain_task_id = []
@@ -456,7 +465,6 @@ def quick_train(algorithm_id: Optional[str]=None,
 
     # Dataset
     dset, dataset_archive, dataset_checksum = _get_or_create_dataset(
-        id=dataset_id,
         dir_path=dataset_dir,
         archive_path=dataset_archive
     )
@@ -468,9 +476,11 @@ def quick_train(algorithm_id: Optional[str]=None,
                         polling=resource_polling)
         DB().create_local_dataset(id=dset.id, checksum=dataset_checksum)
 
+    if not len(datasets) and dset:
+        datasets.append(dset)
     mounts = {}
-    if dset and dataset_hyperparam_name:
-        mounts[dataset_hyperparam_name] = dset
+    if datasets and dataset_hyperparam_name:
+        mounts[dataset_hyperparam_name] = datasets
     if models and model_hyperparam_name:
         mounts[model_hyperparam_name] = models
     if pretrain_tasks and pretrain_hyperparam_name:
@@ -507,13 +517,13 @@ def quick_train(algorithm_id: Optional[str]=None,
                                  train_task_id=train_task.id,
                                  entrypoint=algo.entrypoint_training,
                                  algorithm_id=algo.id,
-                                 dataset_id=dset.id if dset else None,
+                                 dataset_id=','.join([dset.id for dset in datasets]) if datasets else None,
                                  train_params=train_task.train_params,
                                  algorithm_dir=str(algorithm_dir),
                                  dataset_dir=str(dataset_dir),
                                  dataset_archive=dataset_archive,)
     train_profile.create_in_db()
-    return train_task, algo, dset, project
+    return train_task, algo, datasets, project
 
 
 def resume_unfinished_local_train_tasks():
