@@ -20,8 +20,8 @@ class Dataset(Resource):
         数据集描述（长度最大255）
     state
         数据集状态
-    visibility
-        数据集的可见性（默认为3）
+    public
+        数据集是否公开（默认为False）
     upload_time
         数据集上传时间
     filename
@@ -36,8 +36,6 @@ class Dataset(Resource):
         创建者ID
     node_id
         数据集节点ID
-    owner
-        数据集的所有者，以逗号分隔的这些用户的ID拼成的字符串，无多余空格
     load_detail
         初始化时是否加载详情
     """
@@ -51,9 +49,9 @@ class Dataset(Resource):
         },
         # 资源创建/更新请求包体中包含的所有字段
         'payload': {
-            'create': ['name', 'description', 'visibility', 'owner',
+            'create': ['name', 'description', 'public',
                        'filename'],
-            'update': ['id', 'name', 'description', 'visibility', 'owner'],
+            'update': ['id', 'name', 'description', 'public'],
         },
     }
     """
@@ -68,7 +66,7 @@ class Dataset(Resource):
                  name: Optional[str]=None,
                  description: Optional[str]=None,
                  state: Optional[int]=None,
-                 visibility=1,
+                 public=False,
                  upload_time: Optional[Union[datetime, str]]=None,
                  filename: Optional[str]=None,
                  is_zipfile: Optional[bool]=None,
@@ -76,7 +74,6 @@ class Dataset(Resource):
                  size: Optional[str]=None,
                  creator_id: Optional[str]=None,
                  node_id: Optional[str]=None,
-                 owner: Optional[list]=None,
                  load_detail=False):
         """
         Parameters
@@ -89,8 +86,8 @@ class Dataset(Resource):
             数据集描述（长度最大255）
         state
             数据集状态
-        visibility
-            数据集的可见性（默认为1）
+        public
+            数据集是否公开（默认为False）
         upload_time
             数据集上传时间
         filename
@@ -105,16 +102,14 @@ class Dataset(Resource):
             创建者ID
         node_id
             数据集节点ID
-        owner
-            数据集的所有者，以逗号分隔的这些用户的ID拼成的字符串，无多余空格
         load_detail
             初始化时是否加载详情
         """
         super().__init__(id=id, name=name, description=description,
-                         state=state, visibility=visibility,
+                         state=state, public=public,
                          upload_time=upload_time, filename=filename,
                          is_zipfile=is_zipfile, file_path=file_path, size=size,
-                         creator_id=creator_id, node_id=node_id, owner=owner,
+                         creator_id=creator_id, node_id=node_id,
                          load_detail=load_detail)
 
     def __eq__(self, other: Dataset) -> bool:
@@ -124,7 +119,7 @@ class Dataset(Resource):
             self.id == other.id,
             self.name == other.name,
             self.description == other.description,
-            self.visibility == other.visibility,
+            self.public == other.public,
             # self.state == other.state,
             # self.upload_time == other.upload_time,
             # self.filename == other.filename,
@@ -133,7 +128,6 @@ class Dataset(Resource):
             # self.size == other.size,
             # self.creator_id == other.creator_id,
             # self.node_id == other.node_id,
-            # self.owner == other.owner,
         ])
 
     @classmethod
@@ -151,7 +145,7 @@ class Dataset(Resource):
             raise AnyLearnException("请求未能得到有效响应")
         return [
             Dataset(id=d['id'], name=d['name'], description=d['description'],
-                    state=d['state'], visibility=d['visibility'],
+                    state=d['state'], public=d['public'],
                     upload_time=d['upload_time'])
             for d in res
         ]
@@ -175,12 +169,11 @@ class Dataset(Resource):
         res = res[0]
         self.__init__(id=res['id'], name=res['name'],
                       description=res['description'], state=res['state'],
-                      visibility=res['visibility'],
+                      public=res['public'],
                       upload_time=res['upload_time'], filename=res['filename'],
                       is_zipfile=True if res['is_zipfile'] == 1 else False,
                       file_path=res['file'], size=res['size'],
-                      creator_id=res['creator_id'], node_id=res['node_id'],
-                      owner=res['owner'])
+                      creator_id=res['creator_id'], node_id=res['node_id'])
 
     def _namespace(self):
         return "dataset"
