@@ -22,7 +22,6 @@ from anylearn.interfaces.resource import (
     Resource,
     ResourceDownloader,
     ResourceState,
-    ResourceVisibility,
     SyncResourceDownloader,
 )
 from anylearn.applications.train_profile import TrainProfile
@@ -62,12 +61,8 @@ class TrainTask(BaseObject):
         训练任务描述（长度最大255）
     state
         训练任务状态
-    visibility
-        训练任务可见性，和所在训练项目可见性一致
     creator_id
         创建者ID
-    owner
-        训练任务的所有者，和所在训练项目所有者一致
     project_id
         训练项目ID
     algorithm_id
@@ -111,7 +106,7 @@ class TrainTask(BaseObject):
         'payload': {
             'create': ['name', 'description', 'project_id', 'algorithm_id',
                        'algorithm_git_ref', 'train_params', 'envs',
-                       'files', 'visibility', 'resource_request'],
+                       'files', 'resource_request', 'num_nodes', 'nproc_per_node'],
             'update': [],
         },
     }
@@ -127,9 +122,7 @@ class TrainTask(BaseObject):
                  name: Optional[str]=None,
                  description: Optional[str]=None,
                  state: Optional[int]=None,
-                 visibility: Optional[int]=None,
                  creator_id: Optional[str]=None,
-                 owner: Optional[list]=None,
                  project_id: Optional[str]=None,
                  algorithm_id: Optional[str]=None,
                  algorithm_git_ref: Optional[str]=None,
@@ -144,7 +137,9 @@ class TrainTask(BaseObject):
                  hpo_search_space: Optional[str]=None,
                  final_metric: Optional[float]=None,
                  resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
-                 load_detail=False):
+                 load_detail=False,
+                 num_nodes=1,
+                 nproc_per_node=1):
         """
         Parameters
         ----------
@@ -156,12 +151,8 @@ class TrainTask(BaseObject):
             训练任务描述（长度最大255）
         state
             训练任务状态
-        visibility
-            训练任务可见性，和所在训练项目可见性一致
         creator_id
             创建者ID
-        owner
-            训练任务的所有者，和所在训练项目所有者一致
         project_id
             训练项目ID
         algorithm_id
@@ -193,13 +184,13 @@ class TrainTask(BaseObject):
             如未填，则使用Anylearn后端的:obj:`default`资源组中的默认资源套餐。
         load_detail
             初始化时是否加载详情
+        num_nodes
+            训练任务请求的节点数
         """
         self.name = name
         self.description = description
         self.state = state
-        self.visibility = visibility
         self.creator_id = creator_id
-        self.owner = owner
         self.project_id = project_id
         self.algorithm_id = algorithm_id
         self.algorithm_git_ref = algorithm_git_ref
@@ -214,6 +205,8 @@ class TrainTask(BaseObject):
         self.hpo_search_space = hpo_search_space
         self.final_metric = final_metric
         self.resource_request = resource_request
+        self.num_nodes = num_nodes
+        self.nproc_per_node = nproc_per_node
         super().__init__(id=id, load_detail=load_detail)
 
     def finished(self):
@@ -258,8 +251,7 @@ class TrainTask(BaseObject):
         res = res[0]
         self.__init__(id=res['id'], name=res['name'],
                       description=res['description'], state=res['state'],
-                      visibility=res['visibility'],
-                      creator_id=res['creator_id'], owner=res['owner'],
+                      creator_id=res['creator_id'],
                       project_id=res['project_id'],
                       algorithm_id=res['algorithm_id'],
                       algorithm_git_ref=res['algorithm_git_ref'],
@@ -648,8 +640,7 @@ class TrainTask(BaseObject):
                         name: str,
                         description: Optional[str]=None,
                         is_zipfile: bool=False,
-                        visibility: int=ResourceVisibility.PRIVATE,
-                        owner: Optional[list]=None,
+                        public: bool=False,
                         polling: Union[float, int]=5):
         """
         模型文件转存接口
@@ -666,10 +657,9 @@ class TrainTask(BaseObject):
             模型描述。
         is_zipfile : :obj:`bool`
             模型是否为zip文件。默认为False。
-        visibility : :obj:`int`
-            模型的可见性,默认为私有PRIVATE。
-        owner : :obj:`list`
-            模型的所有者。
+        public : :obj:`bool`
+            模型是否公开。默认为False。
+            模型转存后可到前端模型详情中设置模型的协作者。
         polling : :obj:`float|int`
             模型转换中轮询模型状态的时间间隔（单位：秒）。 默认为5秒。
 
@@ -686,10 +676,8 @@ class TrainTask(BaseObject):
             'description': description,
             'algorithm_id': self.algorithm_id,
             'is_zipfile': "1" if is_zipfile else "0",
-            'visibility': visibility,
+            'public': int(public),
         }
-        if isinstance(owner, list) and len(owner):
-            data['owner'] = ','.join(owner)
         res = post_with_token(f"{url_base()}/model/transform",
                               data=data)
         if not res or 'data' not in res:
