@@ -1,4 +1,5 @@
 from pathlib import Path
+from typing import List
 import responses
 from unittest.mock import patch, create_autospec
 
@@ -8,7 +9,6 @@ from anylearn.interfaces.resource import (
     Algorithm,
     Dataset,
     ResourceState,
-    ResourceVisibility,
 )
 from anylearn.utils.errors import (
     AnyLearnException,
@@ -80,7 +80,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "Test-Algo_1.1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "buzhongyao",
                           'is_zipfile': 1,
@@ -88,7 +88,6 @@ class TestQuickTrain(BaseTestCase):
                           'size': 250.41,
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR002",
@@ -106,7 +105,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "TestDset1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "buzhongyao",
                           'is_zipfile': 1,
@@ -114,7 +113,6 @@ class TestQuickTrain(BaseTestCase):
                           'size': 250.41,
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                       }],
                       status=200)
         # Stub train task creation
@@ -128,9 +126,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "TestTrainTask1",
                           'description': "test",
                           'state': TrainTaskState.RUNNING,
-                          'visibility': 2,
                           'creator_id': "USER001",
-                          'owner': ["USER001"],
                           'project_id': "PROJ001",
                           'algorithm_id': "ALGO001",
                           'algorithm_git_ref': 'master',
@@ -145,7 +141,7 @@ class TestQuickTrain(BaseTestCase):
                       }],
                       status=200)
 
-        train_task, algo, dset, project = quick_train(
+        train_task, algo, dsets, project = quick_train(
             algorithm_dir=FAKE_ALGO_OK,
             algorithm_name="Test-Algo_1.1",
             dataset_dir=FAKE_DSET,
@@ -162,8 +158,8 @@ class TestQuickTrain(BaseTestCase):
         self.assertIsInstance(algo, Algorithm)
         self.assertEqual(algo.id, "ALGO001")
         self.assertEqual(algo.name, "Test-Algo_1.1")
-        self.assertIsInstance(dset, Dataset)
-        self.assertEqual(dset.id, "DSET001")
+        self.assertIsInstance(dsets, List)
+        self.assertEqual(dsets[0].id, "DSET001")
         self.assertIsInstance(project, Project)
         self.assertEqual(project.id, "PROJ001")
 
@@ -290,7 +286,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "TestAlgo1",
                           'description': "test",
                           'state': ResourceState.ERROR,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "buzhongyao",
                           'is_zipfile': 1,
@@ -298,7 +294,6 @@ class TestQuickTrain(BaseTestCase):
                           'size': 250.41,
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR002",
@@ -316,7 +311,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "TestDset1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "buzhongyao",
                           'is_zipfile': 1,
@@ -324,7 +319,6 @@ class TestQuickTrain(BaseTestCase):
                           'size': 250.41,
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                       }],
                       status=200)
 
@@ -396,7 +390,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "TestAlgo1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "buzhongyao",
                           'is_zipfile': 1,
@@ -404,7 +398,6 @@ class TestQuickTrain(BaseTestCase):
                           'size': 250.41,
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR002",
@@ -422,7 +415,7 @@ class TestQuickTrain(BaseTestCase):
                           'name': "TestDset1",
                           'description': "test",
                           'state': ResourceState.ERROR,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "buzhongyao",
                           'is_zipfile': 1,
@@ -430,7 +423,6 @@ class TestQuickTrain(BaseTestCase):
                           'size': 250.41,
                           'creator_id': "USER001",
                           'node_id': "NODE001",
-                          'owner': ["USER001"],
                       }],
                       status=200)
 
@@ -453,9 +445,7 @@ class TestQuickTrain(BaseTestCase):
                     'name': "TestTrainTask1",
                     'description': "test",
                     'state': TrainTaskState.FAIL,
-                    'visibility': 2,
                     'creator_id': "USER001",
-                    'owner': ["USER001"],
                     'project_id': "PROJ001",
                     'algorithm_id': "ALGO001",
                     'args': "{\"arg1\":1, \"arg2\":\"test\"}",
@@ -474,9 +464,7 @@ class TestQuickTrain(BaseTestCase):
                     'name': "TestTrainTask1",
                     'description': "test",
                     'state': TrainTaskState.ABORT,
-                    'visibility': 2,
                     'creator_id': "USER001",
-                    'owner': ["USER001"],
                     'project_id': "PROJ001",
                     'algorithm_id': "ALGO001",
                     'args': "{\"arg1\":1, \"arg2\":\"test\"}",
@@ -495,9 +483,7 @@ class TestQuickTrain(BaseTestCase):
                     'name': "TestTrainTask1",
                     'description': "test",
                     'state': TrainTaskState.SUCCESS,
-                    'visibility': 2,
                     'creator_id': "USER001",
-                    'owner': ["USER001"],
                     'project_id': "PROJ001",
                     'algorithm_id': "ALGO001",
                     'args': "{\"arg1\":1, \"arg2\":\"test\"}",
