@@ -7,7 +7,7 @@ import responses
 from urllib.parse import urlencode
 from unittest.mock import patch, create_autospec
 
-from anylearn.interfaces.resource import Model, ResourceVisibility, ResourceState
+from anylearn.interfaces.resource import Model, ResourceState
 from anylearn.interfaces.train_task import TrainTask, TrainTaskState
 from anylearn.utils.errors import AnyLearnException, AnyLearnMissingParamException
 from tests.base_test_case import BaseTestCase
@@ -575,7 +575,7 @@ class TestTrainTask(BaseTestCase):
                           'name': "TestModel1",
                           'description': "test",
                           'state': ResourceState.READY,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "test.tar.gz",
                           'is_zipfile': 1,
@@ -590,7 +590,7 @@ class TestTrainTask(BaseTestCase):
         train_task = TrainTask(results_id="FILE123", algorithm_id="ALGO123")
         owner = ["USER1", "USER2", "USER13"]
         res = train_task.transform_model(
-            "file_path", "name", "description", True, ResourceVisibility.PRIVATE, owner, 1)
+            "file_path", "name", "description", True, False, 1)
         self.assertIsInstance(res, Model)
         self.assertEqual(res.id, "MODE001")
         self.assertEqual(res.state, ResourceState.READY)
@@ -612,7 +612,7 @@ class TestTrainTask(BaseTestCase):
                           'name': "TestModel1",
                           'description': "test",
                           'state': ResourceState.ERROR,
-                          'visibility': ResourceVisibility.PUBLIC,
+                          'public': True,
                           'upload_time': "2020-01-01 00:00",
                           'filename': "test.tar.gz",
                           'is_zipfile': 1,
@@ -628,7 +628,7 @@ class TestTrainTask(BaseTestCase):
         with self.assertRaises(AnyLearnException) as ctx:
             owner = ["USER1", "USER2", "USER13"]
             res = train_task.transform_model(
-                "file_path", "name", "description", True, ResourceVisibility.PRIVATE, owner, 1)
+                "file_path", "name", "description", True, False, 1)
         e = ctx.exception
         self.assertIsInstance(e, AnyLearnException)
         self.assertEqual(e.msg, "Error occured when transforming model")
@@ -638,7 +638,7 @@ class TestTrainTask(BaseTestCase):
         with self.assertRaises(AnyLearnMissingParamException) as ctx:
             owner = ["USER1", "USER2", "USER13"]
             train_task.transform_model(
-                "file_path", "name", "description", True, ResourceVisibility.PRIVATE, owner, 1)
+                "file_path", "name", "description", True, False, 1)
         e = ctx.exception
         self.assertIsInstance(e, AnyLearnMissingParamException)
         self.assertEqual(
@@ -655,7 +655,7 @@ class TestTrainTask(BaseTestCase):
         with self.assertRaises(AnyLearnException) as ctx:
             owner = ["USER1", "USER2", "USER13"]
             train_task.transform_model(
-                "file_path", "name", "description", True, ResourceVisibility.PRIVATE, owner, 1)
+                "file_path", "name", "description", True, False, 1)
         e = ctx.exception
         self.assertIsInstance(e, AnyLearnException)
         self.assertEqual(e.msg, "请求未能得到有效响应")
